summaryrefslogtreecommitdiff
path: root/grc/gui/Param.py
diff options
context:
space:
mode:
authorJosh Blum2009-09-06 01:17:35 -0700
committerJosh Blum2009-09-06 01:17:35 -0700
commite39507bf32666f9b17d2249106aac0d6cbcacc58 (patch)
treece86aefabac458a9e8599ebd26249521437a4f59 /grc/gui/Param.py
parenta6cb9eceeb62593e852b6dea0f640436381ec947 (diff)
downloadgnuradio-e39507bf32666f9b17d2249106aac0d6cbcacc58.tar.gz
gnuradio-e39507bf32666f9b17d2249106aac0d6cbcacc58.tar.bz2
gnuradio-e39507bf32666f9b17d2249106aac0d6cbcacc58.zip
propsdialog tweaks
Diffstat (limited to 'grc/gui/Param.py')
-rw-r--r--grc/gui/Param.py13
1 files changed, 8 insertions, 5 deletions
diff --git a/grc/gui/Param.py b/grc/gui/Param.py
index 9cd31b8a4..b84598e61 100644
--- a/grc/gui/Param.py
+++ b/grc/gui/Param.py
@@ -39,7 +39,7 @@ class InputParam(gtk.HBox):
def update(self):
"""
Set the markup, color, and tooltip.
"""
#set the markup
has_cb = \
@@ -53,6 +53,9 @@ class InputParam(gtk.HBox):
self.entry,
Utils.parse_template(TIP_MARKUP_TMPL, param=self.param).strip(),
)
+ #show/hide
+ if self.param.get_hide() == 'all': self.hide_all()
+ else: self.show_all()
def _handle_changed(self, *args):
"""
@@ -144,7 +147,7 @@ class Param(Element):
def __init__(self): Element.__init__(self)
- def get_input_class(self):
+ def get_input(self, *args, **kwargs):
"""
Get the graphical gtk class to represent this parameter.
An enum requires and combo parameter.
@@ -152,9 +155,9 @@ class Param(Element):
All others get a standard entry parameter.
@return gtk input class
"""
- if self.is_enum(): return EnumParam
- if self.get_options(): return EnumEntryParam
- return EntryParam
+ if self.is_enum(): return EnumParam(*args, **kwargs)
+ if self.get_options(): return EnumEntryParam(*args, **kwargs)
+ return EntryParam(*args, **kwargs)
def get_layout(self):
"""
@@ -39,7 +39,7 @@ class InputParam(gtk.HBox):
def update(self):
"""
- Set the markup, color, and tooltip.
+ Set the markup, color, tooltip, show/hide.
"""
#set the markup